@@ -34,7 +34,7 @@ DBusRunner::DBusRunner(QObject *parent, const KPluginMetaData &pluginMetaData, c
     qRegisterMetaType<QMap<QString, RemoteActions>>("QMap<QString, RemoteActions>");
 
     QString requestedServiceName = pluginMetaData.value(QStringLiteral("X-Plasma-DBusRunner-Service"));
-    m_path = pluginMetaData.value(QStringLiteral("X-Plasma-DBusRunner-Path"));
+    m_path = pluginMetaData.value(QStringLiteral("X-Plasma-DBusRunner-Path"), QStringLiteral("/runner"));
     m_hasUniqueResults = pluginMetaData.value(QStringLiteral("X-Plasma-Runner-Unique-Results"), false);
     m_callLifecycleMethods = pluginMetaData.value(QStringLiteral("X-Plasma-API")) == QLatin1String("DBus2");
 
@@ -93,7 +93,7 @@ DBusRunner::DBusRunner(QObject *parent, const KPluginMetaData &pluginMetaData, c
     for (int i = 0; i < syntaxes.count(); ++i) {
         const QString &query = syntaxes.at(i);
         const QString description = i < descriptionCount ? syntaxDescriptions.at(i) : QString();
-        addSyntax(Plasma::RunnerSyntax(query, description));
+        addSyntax(query, description);
     }
 }
 
@@ -212,8 +212,7 @@ void DBusRunner::match(Plasma::RunnerContext &context)
             m_actionsOnceRequested = true;
             m_actionsForSessionRequested = true;
             auto actions = requestActions();
-            const auto actionsArg = QArgument<QMap<QString, RemoteActions>>("QMap<QString, RemoteActions>", actions);
-            QMetaObject::invokeMethod(this, "createQActionsFromRemoteActions", actionsArg);
+            QMetaObject::invokeMethod(this, "createQActionsFromRemoteActions", QArgument("QMap<QString, RemoteActions>", actions));
         }
     }
     // we scope watchers to make sure the lambda that captures context by reference definitely gets disconnected when this function ends
@@ -379,3 +378,5 @@ QImage DBusRunner::decodeImage(const RemoteImage &remoteImage)
 
     return image;
 }
+
+#include "moc_dbusrunner_p.cpp"
